# -*- coding: utf-8 -*-

from __future__ import unicode_literals


__author__ = 'Nima Shayanfar'
__version__ = '0.1.1'


default_app_config = 'rangefilter2.apps.RangeFilterConfig'


VERSION = __version__
